#
# spec file for package dbus-broker
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           dbus-broker
Version:        11
Release:        lp152.3.6
Summary:        XDG-conforming message bus implementation
License:        Apache-2.0
Group:          Productivity/Telephony/Utilities
Url:            https://github.com/bus1/dbus-broker

Source:         https://github.com/bus1/dbus-broker/archive/v%version.tar.gz
Patch1:         use-system-deps.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  linux-glibc-devel >= 4.13
BuildRequires:  meson
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(audit) >= 2.7
BuildRequires:  pkgconfig(dbus-1) >= 1.10
BuildRequires:  pkgconfig(expat) >= 2.2.3
BuildRequires:  pkgconfig(glib-2.0) >= 2.50
BuildRequires:  pkgconfig(libcdvar) >= 1.7
BuildRequires:  pkgconfig(libclist) >= 3
BuildRequires:  pkgconfig(libcrbtree) >= 3.30
BuildRequires:  pkgconfig(libcsundry) >= 1
BuildRequires:  pkgconfig(libselinux) >= 2.5
BuildRequires:  pkgconfig(libsystemd) >= 230
BuildRequires:  pkgconfig(systemd) >= 230

%description
dbus-broker is an implementation of a message bus as defined by the
D-Bus specification. It has some different characteristics/features
from classic D-Bus:

* No shared medium
* No IPC to implement IPC
* User-based accounting
* Reliable messages
* Just the bus implementation, no external communication
* Local only, no remote transport
* Support for SASL pipelining
* Runtime broker control

%prep
%setup -q
%patch -P 1 -p1

%build
ln -s /bin/true rst2man
%meson -Daudit=true -Dselinux=true
%meson_build

%install
# make install happy
touch build/docs/dbus-broker.1 build/docs/dbus-broker-launch.1
%meson_install
mkdir -p "%buildroot/%_sbindir"
ln -s service "%buildroot/%_sbindir/rcdbus-broker"
find %buildroot/%_mandir -type f -size 0 -delete

%pre
%service_add_pre dbus-broker.service

%post
%service_add_post dbus-broker.service

%preun
%service_del_preun dbus-broker.service

%postun
%service_del_postun dbus-broker.service

%files
%defattr(-,root,root)
%_bindir/dbus-broker*
%_unitdir/*.service
%_prefix/lib/systemd/user/*.service
%_sbindir/rc*
%license LICENSE

%changelog
* Mon Mar  5 2018 jengelh@inai.de
- Update to new upstream release 11
  * The policy-type of the dbus-broker API has been simplified.
    It is now reduced to a policy-batch indexed by uids, in
    combination with a policy-batch indexed either by gid or
    uid-range.
  * The launcher now supports a `--config-file PATH` commandline
    option to override the root configuration file, which is
    still deduced based on the passed scope parameter.
* Tue Feb  6 2018 jengelh@inai.de
- Update to new upstream release 9
  * AddListener() on org.bus1.DBus.Broker now supports UID ranges.
  * dbus-broker.service unit is now ordered before basic.target.
  * The launcher now uses instantiated systemd template units
    when activating a service that has no associated systemd
    service file.
  * The launcher now supports configuration reloading.
  * Activated units now inherit their user from the actual D-Bus
    service, if provided.
* Sun Sep 10 2017 jengelh@inai.de
- Update to new upstream release 4
  * Support for sending SELinux AVC violations to audit rather
    than syslog.
  * Units will now be activated via explicit calls to StartUnit()
    rather than faking a ActivationRequest directed signal. This
    allows to catch startup failures (or rejections) and allows
    to reject all pending activation requests right away.
  * The broker now logs policy violations to the system log.
- Add use-system-deps.diff
* Fri Aug 25 2017 jengelh@inai.de
- Initial package (version 3) for build.opensuse.org
